jsonschema_specifications: The JSON Schema meta-schemas and vocabularies, exposed as a Registry
===============================================================================================

Description
-----------

The JSON Schema meta-schemas and vocabularies, exposed as a Registry

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/jsonschema-specifications/

